@@ -21,6 +21,7 @@
 #'
 #' @useDynLib thurstonianIRT, .registration = TRUE
 #' @import Rcpp
+#' @importFrom RcppParallel RcppParallelLibs
 #' @import methods
 #' @export
 make_stan_data <- function(data) {
@@ -184,7 +185,7 @@ predict_stan_old_data <- function(object, ...) {
         id = as.integer(.data$id),
         trait = as.integer(.data$trait)
       ) %>%
-      select(-.data$par) %>%
+      select(-"par") %>%
       mutate(trait = as.character(factor(.data$trait, labels = traits))) %>%
       arrange(.data$id)
   }
